-----------------------------------------------------------------------------------------------
-- Client Lua Script for LastFive
-- Copyright Celess. Portions (C) Thagar via  public domain FinalFive. All rights reserved.
-----------------------------------------------------------------------------------------------

require "Window"


-----------------------------------------------------------------------------------------------
-- LastFive Module Definition
-----------------------------------------------------------------------------------------------
local _Version,_VersionMinor = 70923,2
local _AddonName,_VersionWindow = "LastFive", 4
local LastFive = {}

-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------

local _eSaveLevel = GameLib.CodeEnumAddonSaveLevel

local _defaultSettings = {		--type: 0 custom, 1 single check, 2 slider, 3 color, 4 radio, 5 text, 6 number, 7 check parts, 8 signal, 9 drop
	-- Normal
	["bMuteAll"] = { default=false, nControlType=1, strControlName="MuteSwitch", fnCallback="OnEnablerButtonChecked" },
	
	-- Base
	bIsOn = true,
	sounds = { -1, -1, -1, -1, 128 },		-- Off, Off, Off, Off, Sound 1

	-- Other

	sSettingsName = "Default",
	nSettingsVersion = 2,
	tSettingsCustom = {	},
}

local _resetSettings = {
	{
		sSettingsName = "Default",
		sSettingsTooltip = "Default settings. These are the settings from when the AddOn was first installed.",
	}, {
		sSettingsName = "Updated",
		sSettingsTooltip = "A more progressive style than Default, with a few of the newer NameView features and refinements. Changes: Range changed from 70 to 90 meters, Cast Bars enabled, Larger Name Font enabled, Max-Health Text disabled, Title disabled, Perspective Opacity enabled.",
		sounds = { 128, 208, 123, 202, 127 },		-- Sound 1, Sound 2, Sound 3, Sound 4, Sound 5
	}, {
		sSettingsName = "Perspective",
		sounds = { 0, 0, 0, 0, 0 },				-- Sound 2, Sound 2, Sound 2, Sound 2, PlayUIWindowCommoditiesExchangeOpen
	}, {
		sSettingsName = "Silent",
		bIsOn = false,
	}, {
		sSettingsName = "Custom",
		sSettingsTooltip = "Custom defaults. Use the Save button at any time to save current settings to this Custom preset. Load them again by choosing this Custom preset from the list.",
	}, {
		sSettingsName = "Durina",
		sounds = { 208, 208, 208, 208, 223 },		-- Sound 2, Sound 2, Sound 2, Sound 2, PlayUIWindowCommoditiesExchangeOpen
	}, {
		sSettingsName = "Pancakes",
	},
}
for _,v in pairs(_resetSettings) do
	_resetSettings[v.sSettingsName:lower()] = v
end


local _eClass = GameLib.CodeEnumClass

local _arSoundChoices = nil			-- eventually populated by localzation files

local _floor = math.floor
local _sqrt = math.sqrt
local _abs = math.abs
local _format = string.format
local _len = string.len
local _tsort = table.sort
local _byte = string.byte
local _char = string.char

local function _dummy() end
local print = _dummy

local function _print(...)
	local s = ""
	for i = 1, select("#",...) do
		s = s .. tostring(select(i,...)) .. " "
	end
	Print(s)
end

local function DeepCopy(o)
	if type(o) ~= 'table' then return o end

	local copy = {}
	for k,v in next, o do copy[k] = DeepCopy(v) end
	return copy
end

local function SettingsCopy(o)
	local copy = {}
	for k,v in next, o do
		if type(v) == "table" and v.nControlType then v = v.default end
		copy[k] = DeepCopy(v)
	end
	return copy
end

local function PostChat(s)
	ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_System, s)
end

local function PlaySound(soundId, psiLevel)
	if soundId > 0 then
		Sound.Play(soundId)
	elseif soundId == 0 then
		Sound.PlayFile(psiLevel..".wav");
	end
end


-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------

function LastFive:new(o)
	o = self
	--o = o or {}
	--setmetatable(o, self)
	--self.__index = self

	o.L = o.L or _L or {}
	setmetatable(o.L, { __index = function(t,k) return tostring(k) end })

	o._AddonName = _AddonName
	o._defaultSettings = _defaultSettings
	o._resetSettings = _resetSettings
	o._print = _print

	return o
end

function LastFive:Init()
	local bHasConfigureFunction = true
	local strConfigureButtonText = _AddonName
	local tDependencies = { }
	Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end


-----------------------------------------------------------------------------------------------
-- LastFive OnLoad
-----------------------------------------------------------------------------------------------

function LastFive:OnLoad()
	self.onXmlDocLoadedCalled = false

	self.userSettings = SettingsCopy(_defaultSettings)

	-- create form
	self.xmlDoc = XmlDoc.CreateFromFile("LastFive.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)

	Apollo.RegisterEventHandler("WindowManagementReady", "OnWindowManagementReady", self)
	Apollo.RegisterEventHandler("LastFive_ShowMenu", "OnShowMenu", self)
	Apollo.RegisterEventHandler("InterfaceMenuListHasLoaded", "OnInterfaceMenuListHasLoaded", self)

	Apollo.RegisterSlashCommand("LF", "OnCommand", self)
	Apollo.RegisterSlashCommand("lf", "OnCommand", self)
	Apollo.RegisterSlashCommand("LastFive", "OnCommand", self)
	Apollo.RegisterSlashCommand("lastfive", "OnCommand", self)
end

function LastFive:OnWindowManagementReady()
	Event_FireGenericEvent("WindowManagementRegister", {strName =  self.L["LastFive Options"], nSaveVersion=_VersionWindow})
end

function LastFive:OnInterfaceMenuListHasLoaded()
	self.bInterfaceMenuLoaded = true
	--Event_FireGenericEvent("InterfaceMenuList_NewAddOn", _AddonName,
	--	{ "LastFive_ShowMenu", "", "CRB_Esper:sprEsper_CombatCount5" })
end


-----------------------------------------------------------------------------------------------
-- LastFive OnDocLoaded
-----------------------------------------------------------------------------------------------

function LastFive:OnDocLoaded()
	if self.xmlDoc == nil or not self.xmlDoc:IsLoaded() then
		return
	end

	Event_FireGenericEvent("OneVersion_ReportAddonInfo", _AddonName, 1, _Version, _VersionMinor)

	-- Load the window

	Apollo.RegisterEventHandler("NextFrame",					"OnFrame", self)

	self.tUpdateTimer = ApolloTimer.Create(0.5, true, "OnUpdateTimer", self)

	self.onXmlDocLoadedCalled = true
	self:InitializeWindows()
end


-----------------------------------------------------------------------------------------------
-- LastFive Functions
-----------------------------------------------------------------------------------------------

function LastFive:OnFrame()
	local o,player = self.userSettings, self.unitPlayer

	if not o.bIsOn or not player then
		return
	end

	local i = player:GetResource(1)
	if i and i >= 1 and i <= 5 and self.psi ~= i  then
		PlaySound(o.sounds[i], i)
		self.psi = i
	end
end


-- visibility timer		-----------------------------------------------------------------------

function LastFive:OnUpdateTimer()
	self:OnUpdateVisibility()
end

function LastFive:OnUpdateVisibility()
	self:UpdateVisibilityCommon()

	self:UpdateVisibilityExternal()
end

function LastFive:UpdateVisibilityCommon()
	local o,w,player = self.userSettings, self.wndMain, self.unitPlayer

	if not player or not player:IsValid() then
		player = GameLib.GetPlayerUnit()
		self.unitPlayer = player

		local eClass = player and player:GetClassId()
		self.bIsEsper = eClass == _eClass.Esper
		self.eClass = eClass or self.eClass

		if player and not self.bIsEsper then									-- not an esper, shut us down
			Apollo.RemoveEventHandler("NextFrame", self)
			if self.tUpdateTimer then self.tUpdateTimer:Stop() end
		end
	end
end

function LastFive:UpdateVisibilityExternal()
	if self.bInterfaceMenuLoaded and self.bIsEsper then							-- and delay load this guy, since theres no way to turn it off afterward
		Event_FireGenericEvent("InterfaceMenuList_NewAddOn", _AddonName,
			{ "LastFive_ShowMenu", "", "CRB_Esper:sprEsper_CombatCount5" })
		self.bInterfaceMenuLoaded = nil
	end
end

function LastFive:UpdatePlayer()
end


-----------------------------------------------------------------------------------------------
-- OptionsForm Form Functions
-----------------------------------------------------------------------------------------------

function LastFive:OnConfigure()
	self:OnOptionsForm()
end

function LastFive:OnCloseWindow()
	self.wndOpts:Close()
end

function LastFive:OnCancel()
	self:OnCloseWindow()
end

function LastFive:OnOK()
	self.configCommitting = true
	self:OnCloseWindow()
end

function LastFive:OnOptionsClosed(wndHandler, wndControl)
	if wndHandler ~= wndControl then
		return
	end

	local wo,L = self.wndOpts, self.L
	if wo and wo:IsValid() then
		wo:Close()
		wo:Destroy()
		self.wndOpts = nil
		self.woChoiceScroll = nil

		self.arSoundButtons = nil
		self.woChoiceSoundScroll = nil

		Event_FireGenericEvent("WindowManagementRemove", {strName = L["LastFive Options"]})
	end
end

function LastFive:OnOptionsForm()
	local L = self.L

	local wo = Apollo.LoadForm(self.xmlDoc, "OptionsForm", nil, self)
	self.wndOpts = wo

	Apollo.LoadForm(self.xmlDoc, "NormalView", wo:FindChild("NormalContent"), self)

	self:OnPanelForm(wo)

	-- fixups

	-- set button references
	self.arSoundButtons = {
		wo:FindChild("SoundDropToggle1"),
		wo:FindChild("SoundDropToggle2"),
		wo:FindChild("SoundDropToggle3"),
		wo:FindChild("SoundDropToggle4"),
		wo:FindChild("SoundDropToggle5")
	}

	-- set static notice
	wo:FindChild("Notice"):SetText(L["_NOTICE"])

	wo:FindChild("Title"):SetText(L["LastFive Options"])

	self:OnCurrentToConfig()
	wo:Invoke()

	Event_FireGenericEvent("WindowManagementAdd", {wnd = wo, strName = L["LastFive Options"], nSaveVersion=_VersionWindow})
end

function LastFive:OnCurrentToConfig()
	local o,wo = self.userSettings, self.wndOpts

	-- Generic managed controls
	self:OnCurrentToPanel(wo)

	wo:FindChild("ResetDropToggle"):SetText(o.sSettingsName)

	-- update buttons
	for i,w in next, self.arSoundButtons do
		local id = o.sounds[i]
		for i2,v2 in next, _arSoundChoices do
			if v2[1] == id then
				w:SetData(v2)									-- lookup table id
				w:SetText(v2[2])								-- sound name
				break
			end
		end
	end

	self:OnEnablerButtonChecked()												-- enable disable buttons
end

function LastFive:OnEnablerButtonChecked()
	local o,wo = self.userSettings, self.wndOpts

	o.bIsOn = not o.bMuteAll

	local bIsOn = o.bIsOn
	for i,w in next, self.arSoundButtons do
		self:SetPushButtonEnabled(w, bIsOn)
		w:GetParent():FindChild("Icon"):SetOpacity(bIsOn and 1 or .6, 20000)
	end
end


-- sound choice

function LastFive:OnSoundButtonCheck(wndHandler, wndControl, eMouseButton)
	local o,wo = self.userSettings, self.wndOpts

	self:OnSoundListHide()											-- clear any checked buttons

	for i,w in next, self.arSoundButtons do
		if w == wndControl then
			self.nSoundButtonId = i; break
		end
	end

	wndControl:SetCheck(true)										-- check our button

	wo:FindChild("ChoiceSoundContainer"):Show(true)					-- show the list
end

function LastFive:OnSoundListHide()
	local o,woScroll = self.userSettings, self.woChoiceSoundScroll
	if not woScroll then return end

	for i,w in next, self.arSoundButtons do
		w:SetCheck(false)											-- uncheck drop buttons
		woScroll:FindChildByUserData(w:GetData()):SetCheck(false)	-- uncheck any known list selections
	end
end

function LastFive:OnSoundListShow()
	local o,wo,woScroll = self.userSettings, self.wndOpts, self.woChoiceSoundScroll

	if not woScroll then
		woScroll = wo:FindChild("ChoiceSoundScroll")
		self.woChoiceSoundScroll = woScroll
		for i,v in ipairs(self._arSoundChoices) do
			local w = Apollo.LoadForm(self.xmlDoc, "ChoiceSoundItem", woScroll, self)
			w:SetData(v)
			w:SetText(v[2])
			w:SetTooltip(v[3] or "")
			if i <= 8 then w:SetTextFlags("DT_CENTER", true) end
		end
		woScroll:ArrangeChildrenVert()
	end

	local tSound = self.arSoundButtons[self.nSoundButtonId]:GetData()
	local w = woScroll:FindChildByUserData(tSound)
	w:SetCheck(true)
	local nPos,h = (tSound[4] - 1) * w:GetHeight(), woScroll:GetHeight()	-- 4 is array index, so is position down the list
	woScroll:SetVScrollPos(nPos < h and 0 or (nPos - (h / 2)))				-- dont scroll if in first page, else center choice
end

function LastFive:OnSoundPick(wndHandler, wndControl, eMouseButton)
	local o,wo,woScroll = self.userSettings, self.wndOpts, self.woChoiceSoundScroll

	local id = self.nSoundButtonId
	local button = self.arSoundButtons[id]

	local tSound = button:GetData()
	woScroll:FindChildByUserData(tSound):SetCheck(false)					-- uncheck old item in list

	tSound = wndControl:GetData()
	if tSound then
		button:SetData(tSound)								-- sound name
		button:SetText(tSound[2])							-- sound name
		o.sounds[id] = tSound[1]							-- sound id
		PlaySound(o.sounds[id], id)
	end

	button:SetCheck(false)
	wo:FindChild("ChoiceSoundContainer"):Show(false)
end


-----------------------------------------------------------------------------------------------
-- LastFive Startup
-----------------------------------------------------------------------------------------------

function LastFive:OnSave(eType)
	local tSave

	if eType == GameLib.CodeEnumAddonSaveLevel.Character then
		local o = self.userSettings

		tSave = { }
	end

	if eType == GameLib.CodeEnumAddonSaveLevel.Realm then
	end

	if tSave then
		local o = self.userSettings

		for k,v in pairs(o) do
			local t = _defaultSettings[k]
			if (type(t) == "table" and t.eSaveLevel or _eSaveLevel.Character) == eType then
				tSave[k] = DeepCopy(v)
			end
		end
	end

	return tSave
end

function LastFive:OnRestore(eType, tSave)
	if tSave then
		local o,_ds = self.userSettings, _defaultSettings

		local nVersion = tSave["nSettingsVersion"] or 0

		for k,v in pairs(tSave) do
			local t = _defaultSettings[k]
			if (type(t) == "table" and t.eSaveLevel or _eSaveLevel.Character) == eType then
				-- migrations
				if nVersion <= 0 and k == "isOn" and not tSave["bIsOn"] then k = "bIsOn" end
				if nVersion <= 1 and k == "bIsOn" then k,v = "bMuteAll", not v; o["bIsOn"] = v end		-- was really bad mixup when converting to newer options format
				-- filters
				if k == "nSettingsVersion" then v = o.nSettingsVersion end
				if k == "sSettingsTooltip" then v = nil end
				o[k] = DeepCopy(v)
			end
			-- migrations
		end
	end

	if eType == GameLib.CodeEnumAddonSaveLevel.Character then
		self:InitializeWindows()
	end
end

function LastFive:InitializeWindows()
	local o = self.userSettings

	self:OnCurrentToCommand()

	-- initialize sound choices
	if not _arSoundChoices then
		_arSoundChoices = self._arSoundChoices
		for i,v in pairs(_arSoundChoices) do
			if not v[3] then v[3] = tostring(v[1]) end
			v[4] = i
		end
	end

	-- re-bind any newly loaded custom reset settings to base custom settings
	self._resetSettingsCustom = self._resetSettingsCustom or _resetSettings.custom
	_resetSettings.custom = setmetatable(o.tSettingsCustom, { __index = self._resetSettingsCustom })

	-- rest needs docload
	if not self.onXmlDocLoadedCalled then
		return
	end

end


-----------------------------------------------------------------------------------------------
-- LastFive Commands
-----------------------------------------------------------------------------------------------

function LastFive:OnShowMenu()				-- used by InterfaceMenuList
	self:OnCommand()
end

function LastFive:OnCurrentToCommand()
	local o = self.userSettings
	print = o.bIsDebug and _print or _dummy
end

function LastFive:OnCommand(sCommand, sArgs)
	local o,wo,L = self.userSettings, self.wndOpts, self.L

	sArgs = sArgs and sArgs:lower() or ""
	local sArg1, sArg2 = sArgs:match("([^ ]+) *(.-) *$")	-- '  aaa   bb cc  ' to 'aaa', 'bb cc'

	if not sArg1 or sArg1 == ""
		or sArg1 == "options"								-- toggle config window
		or sArg1 == "config" or sArg1 == "settings" then
		if wo then
			self:OnOptionsClosed()
		else
			self:OnOptionsForm()
		end
	elseif sArg1 == "optionsopen" then
		if not wo then
			self:OnOptionsForm()
		end
	elseif sArg1 == "optionsclose" then
		if wo then
			self:OnOptionsClosed()
		end

	elseif sArg1 == "reset" then
		local t = (not sArg2 or sArg2 == "") and _resetSettings.default or _resetSettings[sArg2]
		if not t then
			PostChat(_format(L["No reset settings named '%s' for %s."], sArg2, _AddonName))
			return
		end
		o = SettingsCopy(_defaultSettings); self.userSettings = o
		o.tSettingsCustom = _resetSettings.custom
		t.nSettingsVersion = t.nSettingsVersion or o.nSettingsVersion
		self:OnRestore(GameLib.CodeEnumAddonSaveLevel.Realm, t)			-- realm first because char fires init
		self:OnRestore(GameLib.CodeEnumAddonSaveLevel.Character, t)
		if wo and wo:IsValid() then
			self:OnCurrentToConfig()
		end

	elseif sArg1 == "off" then
		o.bIsOn = false
		if wo and wo:IsValid() then
			self:OnCurrentToConfig()
		end
		PostChat(L["LastFive Off"])

	elseif sArg1 == "on" then
		o.bIsOn = true
		if wo and wo:IsValid() then
			self:OnCurrentToConfig()
		end
		PostChat(L["LastFive On"])

	elseif sArg1 == "debug" then
		o.bIsDebug = not o.bIsDebug
		self:OnCurrentToCommand()

	elseif sArg1 == "help" then
		local _addonname = _AddonName:lower()
		PostChat(_format(L["%s commands:"],_AddonName))
		PostChat(_format(L[" /%s - show options"],_addonname))
		PostChat(_format(L[" /%s on - enable sound alert"],_addonname))
		PostChat(_format(L[" /%s off - disable sound alert"],_addonname))
		PostChat(_format(L[" /%s reset - reset to defaults"],_addonname))
		PostChat(_format(L[" /%s reset [name] - reset to named preset"],_addonname))
		PostChat(_format(L[" /%s help - help message"],_addonname))
	end
end


-----------------------------------------------------------------------------------------------
-- LastFive Instance
-----------------------------------------------------------------------------------------------

local LastFiveInst = LastFive:new()
LastFiveInst:Init()

