-----------------------------------------------------------------------------------------------
-- Client Lua Script for LastFive
-- Copyright Celess. Portions (C) Thagar via public domain FinalFive. All rights reserved.
-----------------------------------------------------------------------------------------------

local L,Addon = Apollo.GetAddon("LastFive"):NewLocale("enUS", true)
if not L then return end

L["LastFive Options"] = "LastFive ".. Apollo.GetString("CRB_Options")

L["Off"] = Apollo.GetString("Options_AddonOff")
L["Disable"] = Apollo.GetString("ChatLog_FadeDisable")
L["Sound"] = Apollo.GetString("CRB_Sound")
L["Custom"] = Apollo.GetString("CRB_Custom")

L["LastFive Off"] = "LastFive ".. L["Off"]
L["LastFive On"] = "LastFive ".. Apollo.GetString("Inventory_SortOn")

L["_NOTICE"] = [[
	Using custom sounds:

	Important: Backup existing sounds if you don't want to lose them.

	When "Custom" is selected above, a sound file with a matching PSI number from the LastFive AddOn folder, is used instead. Just replace the corresponsing sound file to use a new custom sound.

	To change a custom sound:
	- Select "Custom" for a PSI point above
	- You will hear the exisiting custom sound for that PSI point
	- Rename your file, outside the LastFive folder, to the PSI number like "2.mp3"
	- Open Houston64.exe, found in Client64 folder in your WildStar install
	- In the main menu, select File > Open...
	- Find the LastFive AddOn folder (see notes below)
	- Select the "toc.xml" file in the LastFive folder, and then "Open" button
	- In the main menu, select Includes > Edit Sounds...
	- Open the Sound you want to import, which you renamed from above
	- Click the Import button on the Import dialog
	- After complete the item will dissappear form the Import dialog
	- You can now safely close Houston
	- Hit some things and test the sounds :)

	Notes:
	- WildSar AddOns are usually found in:
	C:\Users\[Your user name]\AppData\Roaming\NCSOFT\WildStar\AddOns\
	- Five custom sounds are already in place, that need to be copied to save them
	- You do not need to reload or restart WildStar for the sounds to take affect
	- Sounds must be imported with Houston
	- Even existing .wav files need the headers altered
	- Files should be named correctly before import
	- or... files can be renamed after import directly in LastFive folder
	- Never attempt to import a file that is already in the LastFive folder
]]

local sSound = L["Sound"]

Addon._arSoundChoices = {
	{  -1, L["Off"], L["Disable"] },
	{ 128, sSound .. " 1", "128 - PlayUIAlertPopUpTitleReceived" },
	{ 208, sSound .. " 2", "208 - PlayUICraftingOverchargeWarning" },
	{ 123, sSound .. " 3", "123 - PlayUIResurrection" },
	{ 202, sSound .. " 4", "202 - PlayUISocialPartyInviteAccept" },
	{ 127, sSound .. " 5", "127 - PlayUIAlertPopUpRepIncrease" },
	{  13, sSound .. " 6", "13 - PlayUIDatachronBeep" },
	{   0, L["Custom"], "Plays the custom sound in the AddOn folder. See the note below." },
	{ 236, "PlayUIContractTurnInContract" },
	{ 105, "PlayUI53SlideUpDigital" },
--}--[[
	{ 198, "PlayUIQueuePopsAdventure" },
	{ 149, "PlayUIMissionUnlockSolider" },
	{ 171, "PlayUIChallengeGold" },
	{ 235, "PlayUIContractProgressComplete" },
	{ 168, "PlayUIChallengeComplete" },
	{ 107, "PlayUI55ErrorVirtual" },
	{  97, "PlayUI44RotateLeftClickDigital" },
	{ 173, "PlayUIMemoryStart" },
	{ 229, "PlayUIContractAcceptContract" },
	{ 100, "PlayUI46PlaceVirtual" },
	{ 220, "PlayRingtoneSoldier" },
	{  14, "PlayUIDatachronEnd" },
	{  85, "PlayUI22MenuLockOffPhysical" },
	{ 213, "PlayUIWindowCraftingOpen" },
	{  76, "PlayUI11To13GenericPushButtonDigital03" },
	{ 116, "PlayUIHousingHardwareFinalized" },
	{ 251, "PlayUIMTXStoreChoosePaymentOption" },
	{ 141, "PlayUISoldierBossReleased" },
	{ 166, "PlayUIChallengeStarted" },
	{ 139, "PlayUIExplorerSignalDetection3" },
	{ 271, "PlayUILoginRewardsIconAppears" },
	{ 254, "PlayUIMTXStoreClaimItem" },
	{ 201, "PlayUISocialPartyInviteSent" },
	{ 177, "PlayUIMemoryButton2" },
	{ 144, "PlayUISoldierHoldoutFailed" },
	{ 233, "PlayUIContractMilestoneAchieved" },
	{ 188, "PlayUIWindowAccordionClose" },
	{ 122, "PlayUIHousingItemCancelled" },
	{  48, "UIOpeningBag" },
	{ 194, "PlayUINotificationBannerHolo" },
	{ 203, "PlayUISocialPartyInviteDecline" },
	{ 145, "PlayUISoldierWaveReleased" },
	{ 185, "PlayUIButtonMetalSmall" },
	{ 228, "PlayUIContractAbandonContract" },
	{ 267, "PlayUIMTXLoyaltyBarTierHover" },
	{ 156, "PlayUIPathMissionSettlerHubComplete" },
	{  38, "PlayUIMouseSelectUnit" },
	{ 218, "PlayRingtoneScientist" },
	{ 227, "PlayUIPlayerSelectButton" },
	{ 243, "PlayUIEquipFireSetRune" },
	{ 192, "PlayUIButtonHoloLarge" },
	{ 172, "PlayUIAchievementGranted" },
	{ 174, "PlayUIMemoryWin" },
	{  86, "PlayUI23And25GenericToggleOnPhysical01" },
	{  83, "PlayUI20OpenBagVirtual" },
	{ 159, "PlayUISettlerInfrastructureComplete" },
	{ 130, "PlayUIChallengeQuestComplete" },
	{ 222, "PlayUIWindowAuctionHouseOpen" },
	{ 146, "PlayUISoldierHoldoutScreenFlashes" },
	{ 138, "PlayUIExplorerSignalDetection2" },
	{ 129, "PlayUIChallengeQuestOffered" },
	{ 217, "PlayRingtoneExplorer" },
	{ 151, "PlayUIPathMissionComplete" },
	{ 187, "PlayUIWIndowMetalClose" },
	{ 170, "PlayUIChallengeSilver" },
	{ 253, "PlayUIMTXStoreClose" },
	{ 180, "PlayUIMiniMapPing" },
	{ 101, "PlayUI47CancelVirtual" },
	{ 193, "PlayUIButtonHoloSmall" },
	{ 182, "PlayUIArkshipExileWarp" },
	{  43, "PlayUIDatachronSpam" },
	{ 206, "PlayUISocialWhisper" },
	{ 186, "PlayUIWindowMetalOpen" },
	{ 273, "PlayUILoginRewardsPurpleHover" },
	{ 270, "PlayUILoginRewardsClaimRewards" },
	{ 244, "PlayUIEquipFusionRune" },
	{ 258, "PlayUIMTXStorePurchaseFailed" },
	{ 266, "PlayUIMTXCosmicRewardsUnlock05" },
	{ 153, "PlayUIPathMissionExplorerPowerMapComplete" },
	{ 234, "PlayUIContractMilestoneTurnIn" },
	{ 226, "PlayUIVendorRepair" },
	{ 247, "PlayUIEquipLogicRune" },
	{ 204, "PlayUISocialFriendAlert" },
	{ 272, "PlayUILoginRewardsIconTravel" },
	{ 249, "PlayUIEquipWaterRune" },
	{ 175, "PlayUIMemoryLose" },
	{ 178, "PlayUIMemoryButton3" },
	{  74, "PlayUI11To13GenericPushButtonDigital01" },
	{ 152, "PlayUIPathMissionExplorerVistaComplete" },
	{ 268, "PlayUIMTXLoyaltyBarTierHoverTopTier" },
	{  88, "PlayUI24And26GenericToggleOffPhysical01" },
	{ 275, "PlayUICharacterSelectScreen" },
	{ 265, "PlayUIMTXCosmicRewardsUnlock04" },
	{ 169, "PlayUIChallengeBronze" },
	{ 264, "PlayUIMTXCosmicRewardsUnlock03" },
	{ 263, "PlayUIMTXCosmicRewardsUnlock02" },
	{ 155, "PlayUIPathMissionExplorerScavengerHuntComplete" },
	{ 214, "PlayUIWindowPublicEventVoteOpen" },
	{ 262, "PlayUIMTXCosmicRewardsUnlock01" },
	{ 215, "PlayUIWindowPublicEventVoteClose" },
	{ 158, "PlayUISettlerInfrastructureStarted" },
	{ 261, "PlayUIAccountInventoryOpen" },
	{ 260, "PlayUIAccountInventoryClose" },
	{ 259, "PlayUIMTXStoreSignatureScreen" },
	{ 189, "PlayUIWindowAccordionOpen" },
	{ 143, "PlayUISoldierHoldoutAchieved" },
	{ 257, "PlayUIMTXStorePurchaseConfirmation" },
	{ 126, "PlayUIAlertPopUpMessageReceived" },
	{ 256, "PlayUIMTXStorePurchase" },
	{ 164, "PlayUIExplorerScavengerHuntAdvanced" },
	{ 255, "PlayUIMTXStoreOpen" },
	{  87, "PlayUI23And25GenericToggleOnPhysical02" },
	{ 252, "PlayUIMTXStoreClaimCounter" },
	{ 240, "PlayUIEquipEarthRune" },
	{ 190, "PlayUIWindowHoloOpen" },
	{ 269, "PlayUIMTXLoyaltyRewardsBarFillingUp" },
	{ 205, "PlayUIUnlockAbility" },
	{ 248, "PlayUIEquipLogicSetRune" },
	{ 231, "PlayUIContractGoldMilestoneAchieved" },
	{ 136, "PlayUIExplorerSignalDetection0" },
	{ 157, "PlayUIPathMissionUnlock" },
	{ 154, "PlayUIPathMissionExplorerExploreZoneComplete" },
	{ 120, "PlayUIHousingCrateItem" },
	{ 245, "PlayUIEquipLifeRune" },
	{ 242, "PlayUIEquipFireRune" },
	{ 131, "PlayUIChallengeQuestFailed" },
	{ 250, "PlayUIEquipWaterSetRune" },
	{ 160, "PlayUISettlerInfrastructureAdvanced" },
	{  75, "PlayUI11To13GenericPushButtonDigital02" },
	{  96, "PlayUI43RotateRightClickDigital" },
	{ 196, "PlayUIQueuePopsPvP" },
	{ 162, "PlayUIExplorerPowerMapStarted" },
	{ 199, "PlayUIWindowNeedVsGreedOpen" },
	{ 114, "PlayUI07SelectTabPhysical" },
	{ 121, "PlayUIHousingTogglePreview" },
	{ 163, "PlayUIExplorerPowerMapAdvanced" },
	{ 238, "PlayUIEquipAirRune" },
	{  84, "PlayUI21MenuLockOnPhysical" },
	{ 232, "PlayUIContractGoldMilestoneTurnIn" },
	{ 230, "PlayUIContractClickContract" },
	{ 197, "PlayUIQueuePopsDungeon" },
	{ 210, "PlayUICraftingFailure" },
	{ 225, "PlayUIVendorSell" },
	{ 224, "PlayUIVendorBuy" },
	{  99, "PlayUI45LiftVirtual" },
	{ 223, "PlayUIWindowCommoditiesExchangeOpen" },
	{ 221, "PlayUIStoryPanelUrgent" },
	{ 161, "PlayUISettlerHubPayoffComplete" },
	{ 219, "PlayRingtoneSettler" },
	{ 137, "PlayUIExplorerSignalDetection1" },
	{ 184, "PlayUIButtonMetalLarge" },
	{ 216, "PlayUIWindowPublicEventVoteVotingEnd" },
	{ 212, "PlayUICraftingCoordinateMiss" },
	{ 211, "PlayUICraftingCoordinateHit" },
	{ 195, "PlayUIAnimPulseHolo" },
	{ 167, "PlayUIChallengeFailed" },
	{ 165, "PlayUIExplorerClaimTerritoryAdvanced" },
	{ 117, "PlayUIHousingDecor" },
	{  44, "PlayUIDatachronSpamNoVO" },
	{ 134, "PlayUIExplorerButtonEnabled" },
	{ 181, "PlayUIArkshipDominionWarp" },
	{ 209, "PlayUICraftingSuccess" },
	{ 179, "PlayUIMemoryButton4" },
	{ 135, "PlayUIExplorerPathInterfaceOpens" },
	{ 207, "PlayChallengeQuestCancelled" },
	{  12, "PlayUIDatachronIncoming" },
	{ 176, "PlayUIMemoryButton1" },
	{ 241, "PlayUIEquipEarthSetRune" },
	{   9, "PlayUIBagClose" },
	{ 140, "PlayUIExplorerSignalDetection4" },
	{ 200, "PlayUISocialMail" },
	{  78, "PlayUI15ZoomOutPhysical" },
	{ 106, "PlayUI54SlideDownDigital" },
	{ 108, "PlayUI60MessageAlertDigital" },
	{  77, "PlayUI14ZoomInPhysical" },
	{ 239, "PlayUIEquipAirSetRune" },
	{  89, "PlayUI24And26GenericToggleOffPhysical02" },
	{ 118, "PlayUIHousingEnterHouse" },
	{ 115, "PlayUIHousingHardwareAddition" },
	{ 102, "PlayUI48DeleteVirtual" },
	{ 132, "PlayUIExplorerActivateGuideArrow" },
	{ 191, "PlayUIWindowHoloClose" },
	{ 150, "PlayUIPathEpisodeComplete" },
	{  10, "PlayUIBagOpen" },
	{ 119, "PlayUIHousingExitHouse" },
	{ 246, "PlayUIEquipLifeSetRune" },
	{ 142, "PlayUISoldierEnteredRestPeriod" },
	{ 133, "PlayUIExplorerButtonDisabled" },
	{ 237, "PlayUIAddRuneSlot" },
	{  49, "UIOpeningMap" },
}



